@@ -24,39 +24,44 @@ SOFTWARE.
 
 # Imports
 # Files
-import disspy.activity
 import disspy.abstract
-import disspy.application_commands
+import disspy.activity
+import disspy.app_commands
+import disspy.application
+import disspy.bot
 import disspy.channel
-import disspy.client
-import disspy.core
 import disspy.embed
 import disspy.errors
 import disspy.guild
-import disspy.user
 import disspy.reaction
-import disspy.ui
 import disspy.thread
+import disspy.typ
+import disspy.ui
+import disspy.user
 
 # Classes
 from disspy.abstract import (
+    Messageable,
     Channel,
-    Message
+    Message,
+    Thread
 )
 from disspy.activity import (
     Activity,
     ActivityType
 )
-from disspy.application_commands import (
+from disspy.app_commands import (
     ApplicationCommandType,
-    ApplicationCommand,
-    SlashCommand,
-    UserCommand,
-    MessageCommand,
     Context,
     Option,
     OptionType,
-    OptionArgs
+    OptionArgs,
+    StrOption,
+    IntOption,
+    NumOption,
+    BoolOption,
+    UserOption,
+    ChannelOption
 )
 from disspy.channel import (
     DisChannel,
@@ -66,16 +71,15 @@ from disspy.channel import (
     MessageDeleteEvent,
     DmMessageDeleteEvent
 )
-from disspy.client import (
+from disspy.bot import (
     DisBot,
     DisBotStatus,
     DisBotEventType
 )
-from disspy.core import (
+from disspy.http import (
     DisApi,
     DisFlags,
-    JsonOutput,
-    Snowflake
+    JsonOutput
 )
 from disspy.embed import (
     DisEmbed,
@@ -105,7 +109,9 @@ from disspy.thread import (
     DisThread,
     DisPrivateThread
 )
-
+from disspy.state import ConnectionState
+from disspy.webhook import DispyWebhook
+from disspy.application import Application
 
 # Methods for other variables
 def _all_generator(alls: list) -> tuple:
@@ -121,39 +127,27 @@ def _all_generator(alls: list) -> tuple:
     return tuple(result)
 
 
-# Variables
-
-# Version of disspy
-__version__ = "0.6.2.1"
-
-# Link to GitHub repo
+# Info about package
+__version__ = "0.6.3"
+__pkgname__ = "disspy"
+__description__ = "Dispy - package for creating bots in discord written in Python"
 __github__ = "https://github.com/itttgg/dispy"
 
-# Link to stable version of package
-__latest_version__ = "https://github.com/itttgg/dispy/releases/latest"
-
-# Description of package
-__description__ = "Dispy - package for creating bots in discord."
-
-# Name of package
-__packagename__ = "dispy"
-
-
 # __all__
 __alls__: list = [
-    disspy.activity.__all__,
     disspy.abstract.__all__,
-    disspy.application_commands.__all__,
+    disspy.activity.__all__,
+    disspy.app_commands.__all__,
+    disspy.application.__all__,
+    disspy.bot.__all__,
     disspy.channel.__all__,
-    disspy.client.__all__,
-    disspy.core.__all__,
     disspy.embed.__all__,
     disspy.errors.__all__,
     disspy.guild.__all__,
-    disspy.user.__all__,
     disspy.reaction.__all__,
+    disspy.thread.__all__,
     disspy.ui.__all__,
-    disspy.thread.__all__
+    disspy.user.__all__
 ]
 
 __all__: tuple = _all_generator(__alls__)
