@@ -26,15 +26,14 @@ from typing import (
     Optional,
     Union,
     List,
-    NoReturn,
     final,
-    Any
+    TypedDict
 )
 
 from json import dumps
 from aiohttp import ClientSession
 from requests import get
-from disspy.typ import Url
+from disspy.typ import Url, SupportsStr
 
 
 from disspy.abstract import Message, Channel
@@ -55,9 +54,18 @@ __all__: tuple = (
 )
 
 
+class MessagePayload(TypedDict):
+    """MessagePayload
+    Text message payload (typed)
+    """
+    content: str
+    embeds: Optional[list]
+    components: Optional[list]
+
+
 class _SendingRestHandler:
     @staticmethod
-    async def execute(channel_id: int, payload: dict, token: str) -> dict:
+    async def execute(channel_id: int, payload: MessagePayload, __session: ClientSession) -> dict:
         """execute
         Send messages in channels
 
@@ -69,17 +77,15 @@ class _SendingRestHandler:
         Returns:
             dict: Json output
         """
-        async with ClientSession(headers={'Authorization': f'Bot {token}',
-                                          'content-type': 'application/json'}) as session:
-            _u = f"https://discord.com/api/v9/channels/{channel_id}/messages"
+        __url = f"https://discord.com/api/v9/channels/{channel_id}/messages"
 
-            async with session.post(_u, data=dumps(payload)) as data:
-                j = await data.json()
+        async with __session.post(__url, data=dumps(payload)) as data:
+            j = await data.json()
 
-                return j
+            return j
 
     @staticmethod
-    async def put_without_payload(url: Url, token):
+    async def put_without_payload(url: Url, __session: ClientSession):
         """put_without_payload
         PUT method wtthout payload
 
@@ -87,12 +93,10 @@ class _SendingRestHandler:
             url (Url): url for operation
             token (str): Bot token
         """
-        async with ClientSession(headers={'Authorization': f'Bot {token}',
-                                          'content-type': 'application/json'}) as session:
-            await session.put(url)
+        await __session.put(url)
 
     @staticmethod
-    async def delete(url: Url, token: str):
+    async def delete(url: Url, __session: ClientSession):
         """delete
         DELETE method
 
@@ -100,12 +104,10 @@ class _SendingRestHandler:
             url (Url): url for operation
             token (str): Bot token
         """
-        async with ClientSession(headers={'Authorization': f'Bot {token}',
-                                          'content-type': 'application/json'}) as session:
-            await session.delete(url=url)
+        await __session.delete(url=url)
 
     @staticmethod
-    async def post_without_payload(url: Url, token: str):
+    async def post_without_payload(url: Url, __session: ClientSession):
         """post_without_payload
         POST method wtthout payload
 
@@ -113,26 +115,22 @@ class _SendingRestHandler:
             url (Url): url for operation
             token (str): Bot token
         """
-        async with ClientSession(headers={'Authorization': f'Bot {token}',
-                                          'content-type': 'application/json'}) as session:
-            await session.post(url=url)
+        await __session.post(url=url)
 
     @staticmethod
-    async def create_reaction(endpoint, token):
+    async def create_reaction(endpoint: str, __session: ClientSession):
         """create_reaction()
 
         Args:
             endpoint (str): Url endpoint
             token (str): Bot token
         """
-        async with ClientSession(headers={'Authorization': f'Bot {token}',
-                                          'content-type': 'application/json'}) as session:
-            _u = f"https://discord.com/api/v10{endpoint}"
+        url = f"https://discord.com/api/v10{endpoint}"
 
-            await session.put(_u)
+        await __session.put(url)
 
     @staticmethod
-    async def delete_message(url, token):
+    async def delete_message(url: Url, __session: ClientSession):
         """delete_message
         Delete message
 
@@ -140,14 +138,12 @@ class _SendingRestHandler:
             url (str): Url of message
             token (str): Bot token
         """
-        async with ClientSession(headers={'Authorization': f'Bot {token}',
-                                          'content-type': 'application/json'}) as session:
-            await session.delete(url=url)
+        await __session.delete(url=url)
 
 
 class _GettingChannelData:
     @staticmethod
-    def execute(channel_id, token):
+    def execute(channel_id: int, token: str):
         """execute
         Get channel data by id
 
@@ -164,7 +160,7 @@ class _GettingChannelData:
         return get(_u, headers=_h).json()
 
     @staticmethod
-    def fetch(channel_id, token, message_id):
+    def fetch(channel_id: int, token: str, message_id: int):
         """fetch
         Fetch message by channel id and message id
 
@@ -184,7 +180,7 @@ class _GettingChannelData:
 
 class _GettingGuildData:
     @staticmethod
-    def execute(guild_id, token):
+    def execute(guild_id: int, token: str):
         """execute
         Get guild data
 
@@ -206,12 +202,12 @@ class DisMessage(Message):
     """
     Message in channel
     """
-    def __init__(self, _data, _token):
+    def __init__(self, _data, __token, __session):
         super().__init__(_data["type"])
 
         self.json = _data
 
-        self.channel = DisChannel(_data["channel_id"], _token)
+        self.channel = DisChannel(_data["channel_id"], __token, __session)
 
         self.content: str = str(_data["content"])
 
@@ -237,9 +233,11 @@ class DisMessage(Message):
 
         self.id: int = int(_data["id"])
 
-        self._t = _token
+        self._t = __token
+        self.session = __session
 
-    async def reply(self, content: Optional[str] = None, embeds: Optional[List[DisEmbed]] = None):
+    async def reply(self, content: Optional[SupportsStr] = None,
+                    embeds: Optional[List[DisEmbed]] = None):
         """reply
         Reply to message
 
@@ -272,7 +270,7 @@ class DisMessage(Message):
         if not embeds and not content:
             return
 
-        await _SendingRestHandler.execute(self.channel.id, _d, self._t)
+        await _SendingRestHandler.execute(self.channel.id, _d, self.session)
 
     async def create_reaction(self, emoji: Union[DisEmoji, str]) -> DisOwnReaction:
         """create_reaction
@@ -291,9 +289,9 @@ class DisMessage(Message):
                 emoji = emoji.unicode
 
         await _SendingRestHandler.create_reaction(
-            f"/channels/{self.channel.id}/messages/{self.id}/reactions/{emoji}/@me", self._t)
+            f"/channels/{self.channel.id}/messages/{self.id}/reactions/{emoji}/@me", self.session)
 
-        return DisOwnReaction(emoji, self.id, self.channel.id, self._t)
+        return DisOwnReaction(emoji, self.id, self.channel.id, self._t, self.session)
 
     async def delete(self):
         """delete
@@ -301,53 +299,7 @@ class DisMessage(Message):
         """
         _u = f"https://discord.com/api/v10/channels/{self.channel.id}/messages/{self.id}"
 
-        await _SendingRestHandler.delete_message(_u, self._t)
-
-
-@final
-class _ShowonlyContext:
-    def __init__(self, message: DisMessage, token: str, channel_id: int) -> NoReturn:
-        self._t = token
-        self._channel_id = int(channel_id)
-
-        self._content = message.content
-
-        self._embeds = message.embeds
-
-    async def _send(self, payload) -> DisMessage:
-        data = await _SendingRestHandler.execute(self._channel_id, payload, self._t)
-
-        return DisMessage(data, self._t)
-
-    async def content(self) -> DisMessage:
-        """content
-        Send only content
-
-        Returns:
-            DisMessage: Showed message
-        """
-        _payload = {
-            "content": self._content
-        }
-
-        _m = await self._send(_payload)
-
-        return _m
-
-    async def embeds(self) -> DisMessage:
-        """embeds
-        Send only embeds
-
-        Returns:
-            DisMessage: Showed message
-        """
-        _payload = {
-            "embeds": self._embeds
-        }
-
-        _m = await self._send(_payload)
-
-        return _m
+        await _SendingRestHandler.delete_message(_u, self.session)
 
 
 @final
@@ -355,7 +307,7 @@ class DisChannel(Channel):
     """
     The class for sending messages to discord channels and fetching messages in channels
     """
-    def __init__(self, channel_id: int, _token):
+    def __init__(self, channel_id: int, __token, __session):
         """
         Creating an object DisChannel
 
@@ -364,8 +316,9 @@ class DisChannel(Channel):
         """
         super().__init__()
 
-        self._t = _token
+        self._t = __token
         self.id = channel_id
+        self.session = __session
 
         _data = _GettingChannelData.execute(self.id, self._t)
 
@@ -374,7 +327,7 @@ class DisChannel(Channel):
 
             _d = _GettingGuildData.execute(g_id, self._t)
 
-            self.guild = DisGuild(_d, self._t)
+            self.guild = DisGuild(_d, self._t, self.session)
         except KeyError:
             pass
 
@@ -388,7 +341,8 @@ class DisChannel(Channel):
         """
         return self.id == other.id
 
-    async def send(self, content: Optional[str] = None, embeds: Optional[List[DisEmbed]] = None,
+    async def send(self, content: Optional[SupportsStr] = None,
+                   embeds: Optional[List[DisEmbed]] = None,
                    action_row: Optional[ActionRow] = None) -> Union[DisMessage, None]:
         """
         Sending messages to discord channel
@@ -427,46 +381,12 @@ class DisChannel(Channel):
                 del _payload["components"]
 
         if _payload:
-            data = await _SendingRestHandler.execute(self.id, _payload, self._t)
+            data = await _SendingRestHandler.execute(self.id, _payload, self.session)
 
-            return DisMessage(data, self._t)
+            return DisMessage(data, self._t, self.session)
 
         return None
 
-    async def show(self, message: DisMessage):
-        """show
-        Send all info about message in channel
-
-        Args:
-            message (DisMessage): Message for showing
-
-        Returns:
-            DisMessage: Showed message
-        """
-        json_data = {}
-
-        if message.content:
-            json_data.setdefault("content", message.content)
-
-        if message.embeds:
-            json_data.setdefault("embeds", message.embeds)
-
-        data = await _SendingRestHandler.execute(self.id, json_data, self._t)
-
-        return DisMessage(data, self._t)
-
-    def showonly(self, message: DisMessage) -> _ShowonlyContext:
-        """showonly
-        show() method, but send only embeds or content
-
-        Args:
-            message (DisMessage): Message for showing
-
-        Returns:
-            _ShowonlyContext: Context for showing
-        """
-        return _ShowonlyContext(message, self._t, self.id)
-
     def fetch(self, message_id: int) -> DisMessage:
         """
         Fetch message
@@ -476,7 +396,7 @@ class DisChannel(Channel):
         """
         data = _GettingChannelData.fetch(self.id, self._t, message_id)
 
-        return DisMessage(data, self._t)
+        return DisMessage(data, self._t, self.session)
 
     async def pin(self, message_id: int):
         """pin
@@ -487,7 +407,7 @@ class DisChannel(Channel):
         """
         _u = f"https://discord.com/api/v10/channels/{self.id}/pins/{message_id}"
 
-        await _SendingRestHandler.put_without_payload(_u, self._t)
+        await _SendingRestHandler.put_without_payload(_u, self.session)
 
     async def unpin(self, message_id: int):
         """unpin
@@ -498,7 +418,7 @@ class DisChannel(Channel):
         """
         _u = f"https://discord.com/api/v10/channels/{self.id}/pins/{message_id}"
 
-        await _SendingRestHandler.delete(_u, self._t)
+        await _SendingRestHandler.delete(_u, self.session)
 
     async def delete(self):
         """delete
@@ -506,7 +426,7 @@ class DisChannel(Channel):
         """
         _u = f"https://discord.com/api/v10/channels/{self.id}"
 
-        await _SendingRestHandler.delete(_u, self._t)
+        await _SendingRestHandler.delete(_u, self.session)
 
     async def typing(self):
         """typing
@@ -514,7 +434,7 @@ class DisChannel(Channel):
         """
         _u = f"https://discord.com/api/v10/channels/{self.id}/typing"
 
-        await _SendingRestHandler.post_without_payload(_u, self._t)
+        await _SendingRestHandler.post_without_payload(_u, self.session)
 
 
 @final
@@ -522,18 +442,20 @@ class DmMessage(Message):
     """
     Message in DM channel
     """
-    def __init__(self, data, token):
+    def __init__(self, data, token, session):
         super().__init__(data["type"], True)
 
         self.json = data
         self._t = token
+        self.session = session
 
         self.id = data["id"]
 
         self.content = data["content"]
-        self.channel = DisDmChannel(data["channel_id"], self._t)
+        self.channel = DisDmChannel(data["channel_id"], self._t, session)
 
-    async def reply(self, content: Optional[Any] = None, embeds: Optional[List[DisEmbed]] = None):
+    async def reply(self, content: Optional[SupportsStr] = None,
+                    embeds: Optional[List[DisEmbed]] = None):
         """reply
         Reply to message
 
@@ -566,7 +488,7 @@ class DmMessage(Message):
         if not embeds and not content:
             return
 
-        await _SendingRestHandler.execute(self.channel.id, _d, self._t)
+        await _SendingRestHandler.execute(self.channel.id, _d, self.session)
 
     async def create_reaction(self, emoji: Union[DisEmoji, str]) -> DisOwnReaction:
         """create_reaction
@@ -585,9 +507,9 @@ class DmMessage(Message):
                 emoji = emoji.unicode
 
         await _SendingRestHandler.create_reaction(
-            f"/channels/{self.channel.id}/messages/{self.id}/reactions/{emoji}/@me", self._t)
+            f"/channels/{self.channel.id}/messages/{self.id}/reactions/{emoji}/@me", self.session)
 
-        return DisOwnReaction(emoji, self.id, self.channel.id, self._t)
+        return DisOwnReaction(emoji, self.id, self.channel.id, self._t, self.session)
 
 
 @final
@@ -595,7 +517,7 @@ class DisDmChannel(Channel):
     """
     The class for sending messages to discord DMchannels and fetching messages in DMchannels
     """
-    def __init__(self, dm_id: dict, token):
+    def __init__(self, dm_id: dict, __token, __session):
         """
         Init object
         -----
@@ -604,12 +526,14 @@ class DisDmChannel(Channel):
         """
         super().__init__()
 
-        _data = _GettingChannelData.execute(dm_id, token)
+        _data = _GettingChannelData.execute(dm_id, __token)
 
         self.id = _data["id"]
-        self._t = token
+        self._t = __token
+        self.session = __session
 
-    async def send(self, content: Optional[str] = None, embeds: Optional[List[DisEmbed]] = None,
+    async def send(self, content: Optional[SupportsStr] = None,
+                   embeds: Optional[List[DisEmbed]] = None,
                    action_row: Optional[ActionRow] = None) -> Union[DisMessage, None]:
         """
         Sending messages to discord channel
@@ -648,9 +572,9 @@ class DisDmChannel(Channel):
                 del _payload["components"]
 
         if _payload:
-            data = await _SendingRestHandler.execute(self.id, _payload, self._t)
+            data = await _SendingRestHandler.execute(self.id, _payload, self.session)
 
-            return DisMessage(data, self._t)
+            return DisMessage(data, self._t, self.session)
 
         return None
 
@@ -663,22 +587,22 @@ class DisDmChannel(Channel):
         """
         data = _GettingChannelData.fetch(self.id, self._t, message_id)
 
-        return DisMessage(data, self._t)
+        return DisMessage(data, self._t, self.session)
 
 
 class MessageDeleteEvent:
     """
     MESSAGE_DELETE event class with info about event
     """
-    def __init__(self, data: dict, token: str):
+    def __init__(self, data: dict, token: str, session):
         self.message_id = data['id']
-        self.channel = DisChannel(data['channel_id'], token)
+        self.channel = DisChannel(data['channel_id'], token, session)
 
 
 class DmMessageDeleteEvent:
     """
     MESSAGE_DELETE event class with info about event, but in DM channel
     """
-    def __init__(self, data: dict, token: str):
+    def __init__(self, data: dict, token: str, session):
         self.message_id = data['id']
-        self.channel = DisDmChannel(data['channel_id'], token)
+        self.channel = DisDmChannel(data['channel_id'], token, session)
