@@ -43,96 +43,104 @@ import disspy.user
 
 Json = NewType("Json", dict)
 
+_mainurl = "https://discord.com/api/v10"
+
 class _SendingRestHandler:
-    _mainurl = "https://discord.com/api/v10"
 
-    def __init__(self, token: str):
-        self.hdrs = {'Authorization': f'Bot {token}', "content-type": "application/json"}
-
-    def _gen_url(self, endpoint) -> str:
-        return self._mainurl + endpoint
-
-    async def post(self, endpoint, _payload=None):
+    @staticmethod
+    async def post(endpoint, __session: ClientSession, _payload=None):
         """post
         POST method
 
         Args:
             endpoint (str): Url endpoint
+            __session (ClientSession): Aiohttp client session
             _payload (dict, optional): Json data. Defaults to None.
 
         Returns:
             dict: Json output
         """
-        async with ClientSession(headers=self.hdrs) as session:
-            if _payload:
-                async with session.post(self._gen_url(endpoint), data=json.dumps(_payload)) as data:
-                    j = await data.json()
+        _url = _mainurl + endpoint
 
-                    return j
+        if _payload:
+            async with __session.post(_url, data=json.dumps(_payload)) as data:
+                j = await data.json()
 
-            else:
-                async with session.post(self._gen_url(endpoint)) as data:
-                    j = await data.json()
+                return j
 
-                    return j
+        else:
+            async with __session.post(_url) as data:
+                j = await data.json()
 
-    async def patch(self, endpoint, _payload):
+                return j
+
+    @staticmethod
+    async def patch(endpoint, _payload, __session: ClientSession):
         """patch
         PATCH method
 
         Args:
             endpoint (str): Url endpoint
             _payload (dict): Json data
+            __session (ClientSession): Aiohttp client session
 
         Returns:
             dict: Json output
         """
-        async with ClientSession(headers=self.hdrs) as session:
-            async with session.patch(self._gen_url(endpoint), data=json.dumps(_payload)) as data:
-                j = await data.json()
+        _url = _mainurl + endpoint
 
-                return j
+        async with __session.patch(_url, data=json.dumps(_payload)) as data:
+            j = await data.json()
 
-    async def put(self, endpoint, _payload=None):
+            return j
+
+    @staticmethod
+    async def put(endpoint, __session: ClientSession, _payload=None):
         """put
         PUT method
 
         Args:
             endpoint (str): Url endpoint
+            __session (ClientSession): Aiohttp client session
             _payload (dict, optional): Json data. Defaults to None.
 
         Returns:
             dict: Json output
         """
-        async with ClientSession(headers=self.hdrs) as session:
-            if _payload:
-                async with session.put(self._gen_url(endpoint), data=_payload) as data:
-                    j = await data.json()
+        _url = _mainurl + endpoint
 
-                    return j
-            else:
-                async with session.put(self._gen_url(endpoint)) as data:
-                    j = await data.json()
+        if _payload:
+            async with __session.put(_url, data=_payload) as data:
+                j = await data.json()
 
-                    return j
+                return j
+        else:
+            async with __session.put(_url) as data:
+                j = await data.json()
 
-    async def delete(self, endpoint):
+                return j
+
+    @staticmethod
+    async def delete(endpoint, __session: ClientSession):
         """delete
         DELETE method
 
         Args:
             endpoint (str): Url endpoint
+            __session (ClientSession): Aiohttp client session
 
         Returns:
             dict: Json output
         """
-        async with ClientSession(headers=self.hdrs) as session:
-            async with session.delete(self._gen_url(endpoint)) as data:
-                j = await data.json()
+        _url = _mainurl + endpoint
 
-                return j
+        async with __session.delete(_url) as data:
+            j = await data.json()
 
-    def get(self, endpoint):
+            return j
+
+    @staticmethod
+    def get(endpoint, hdrs):
         """get
         GET method
 
@@ -142,7 +150,9 @@ class _SendingRestHandler:
         Returns:
             dict: Json output
         """
-        data = get(self._gen_url(endpoint), headers=self.hdrs).json()
+        _url = _mainurl + endpoint
+
+        data = get(_url, headers=hdrs).json()
 
         return data
 
@@ -151,8 +161,9 @@ class DisGuildTemplate:
     """
     Guild Template for copying channels, roles and other information to other guild
     """
-    def __init__(self, data: Json, token: str) -> None:
+    def __init__(self, data: Json, token: str, __session: ClientSession) -> None:
         self._t: str = str(token)
+        self.session = __session
 
         self.code: str = data["code"]
         self.name = data["name"]
@@ -184,8 +195,8 @@ class DisGuildTemplate:
         if not name:
             del _payload["name"]
 
-        await _SendingRestHandler(self._t).patch(f"/guilds/{self.guild_id}/templates/{self.code}",
-                                                 _payload)
+        await _SendingRestHandler.patch(f"/guilds/{self.guild_id}/templates/{self.code}",
+                                                 _payload, self.session)
 
         if name:
             self.name = name
@@ -197,13 +208,13 @@ class DisGuildTemplate:
         """delete
         Delete template
         """
-        await _SendingRestHandler(self._t).delete(f"/guilds/{self.guild_id}/templates/{self.code}")
+        await _SendingRestHandler.delete(f"/guilds/{self.guild_id}/templates/{self.code}", self.session)
 
     async def sync(self):
         """sync
         Sync template
         """
-        await _SendingRestHandler(self._t).put(f"/guilds/{self.guild_id}/templates/{self.code}")
+        await _SendingRestHandler.put(f"/guilds/{self.guild_id}/templates/{self.code}", self.session)
 
     async def create_guild(self, name: Text) -> int:
         """create_guild
@@ -219,7 +230,7 @@ class DisGuildTemplate:
             "name": name
         }
 
-        j = await _SendingRestHandler(self._t).post(f"/guilds/templates/{self.code}", _payload)
+        j = await _SendingRestHandler.post(f"/guilds/templates/{self.code}", self.session, _payload)
 
         return int(j['id'])
 
@@ -238,7 +249,7 @@ class DisGuild:
     --------
     :var _t: Token of the bot
     """
-    def __init__(self, data: Json, token: Text):
+    def __init__(self, data: Json, token: Text, __session: ClientSession):
         """
         init object
 
@@ -247,6 +258,7 @@ class DisGuild:
         """
         self.id = data["id"]
         self._t = token
+        self.session = __session
 
     async def create_template(self, name: Text, description: Text):
         """create_template()
@@ -260,6 +272,6 @@ class DisGuild:
             "description": description
         }
 
-        j = await _SendingRestHandler(self._t).post(f"/guilds/{self.id}/templates", _payload)
+        j = await _SendingRestHandler.post(f"/guilds/{self.id}/templates", self.session, _payload)
 
-        return DisGuildTemplate(j, self._t)
+        return DisGuildTemplate(j, self._t, self.session)
