@@ -22,8 +22,10 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
-
-from typing import NewType
+from abc import abstractmethod
+from typing import (
+    Protocol
+)
 
 
 class TypeOf:
@@ -54,4 +56,15 @@ class Event:
         return list(args)[1]
 
 
-Url = NewType("Url", str)
+class SupportsStr(Protocol):
+    """SupportsStr
+    Protocol with __str__() method
+    """
+    @abstractmethod
+    def __str__(self) -> str:
+        pass
+
+
+# Custom types
+Url = str
+MISSING = None
